==> nextcloud-29.0.7.tar.bz2: nextcloud/apps/serverinfo/l10n/es_MX.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Información de CPU no disponible",
    "Load average: {cpu} (last minute)" : "Promedio de carga: {cpu} (último minuto)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Uso actual: {memUsageBytes}",
    "RAM info not available" : "Información de RAM no disponible",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Uso actual: {swapUsageBytes}",
    "SWAP info not available" : "Información de SWAP no disponible",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitoreo",
    "Monitoring app with useful server information" : "App de monitoreo con información útil del servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Provee información útil del servidor como carga del CPU, uso de RAM, uso de disco, número de usuarios, etc.",
    "Operating System:" : "Sistema operativo:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Procesador desconocido",
    "Memory:" : "Memoria:",
    "Server time:" : "Hora del servidor:",
    "Uptime:" : "Tiempo de actividad:",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memoria",
    "Disk" : "Disco",
    "Mount:" : "Montaje:",
    "Filesystem:" : "Sistema de archivos:",
    "Size:" : "Tamaño:",
    "Available:" : "Disponible:",
    "Used:" : "Usado:",
    "Files:" : "Archivos:",
    "Storages:" : "Almacenamiento:",
    "Free Space:" : "Espacio Libre:",
    "Network" : "Red",
    "Hostname:" : "Nombre del host:",
    "Gateway:" : "Puerta de enlace:",
    "Status:" : "Estado:",
    "Speed:" : "Velocidad:",
    "Duplex:" : "Dúplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuarios activos",
    "Total users:" : "Total de usuarios:",
    "24 hours:" : "24 horas:",
    "1 hour:" : "1 hora:",
    "5 mins:" : "5 minutos:",
    "Shares" : "Elementos compartido",
    "Users:" : "Usuarios:",
    "Groups:" : "Grupos:",
    "Links:" : "Enlaces:",
    "Emails:" : "Correos electrónicos:",
    "Federated sent:" : "Federaciones enviadas:",
    "Federated received:" : "Federaciones recibidas:",
    "Talk conversations:" : "Conversaciones de Talk:",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory limit:" : "Límite de memoria:",
    "Max execution time:" : "Tiempo máximo de ejecución:",
    "Upload max size:" : "Tamaño máximo de carga:",
    "OPcache Revalidate Frequency:" : "Frecuencia de revalidación de OPcache:",
    "Extensions:" : "Extensiones:",
    "Unable to list extensions" : "No se pueden enumerar las extensiones",
    "Show phpinfo" : "Mostrar phpinfo",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Herramienta de monitoreo externa",
    "Use this end point to connect an external monitoring tool:" : "Utilice este endpoint para conectar una herramienta de monitoreo externa.",
    "Copy" : "Copiar",
    "Output in JSON" : "Salida en JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Omitir actualizaciones de la aplicación (incluir las actualizaciones de las aplicaciones enviará una solicitud externa al app store)",
    "Skip server update" : "Omitir actualización del servidor",
    "To use an access token, please generate one then set it using the following command:" : "Para usar un token de acceso, por favor genere uno y luego configúrelo usando el siguiente comando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Luego pase el token con el encabezado \"NC-Token\" cuando solicite la URL anterior.",
    "DNS:" : "DNS:"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-30.0.12.tar.bz2: nextcloud/apps/serverinfo/l10n/es_MX.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Información de CPU no disponible",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Uso actual: {memUsageBytes}",
    "RAM info not available" : "Información de RAM no disponible",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Uso actual: {swapUsageBytes}",
    "SWAP info not available" : "Información de SWAP no disponible",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitoreo",
    "Monitoring app with useful server information" : "App de monitoreo con información útil del servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Provee información útil del servidor como carga del CPU, uso de RAM, uso de disco, número de usuarios, etc.",
    "Operating System:" : "Sistema operativo:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Procesador desconocido",
    "Memory:" : "Memoria:",
    "Server time:" : "Hora del servidor:",
    "Uptime:" : "Tiempo de actividad:",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memoria",
    "Disk" : "Disco",
    "Mount:" : "Montaje:",
    "Filesystem:" : "Sistema de archivos:",
    "Size:" : "Tamaño:",
    "Available:" : "Disponible:",
    "Used:" : "Usado:",
    "Files:" : "Archivos:",
    "Storages:" : "Almacenamiento:",
    "Free Space:" : "Espacio Libre:",
    "Network" : "Red",
    "Hostname:" : "Nombre del host:",
    "Gateway:" : "Puerta de enlace:",
    "Status:" : "Estado:",
    "Speed:" : "Velocidad:",
    "Duplex:" : "Dúplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuarios activos",
    "Last hour" : "Última hora",
    "Shares" : "Elementos compartido",
    "Users:" : "Usuarios:",
    "Groups:" : "Grupos:",
    "Links:" : "Enlaces:",
    "Emails:" : "Correos electrónicos:",
    "Federated sent:" : "Federaciones enviadas:",
    "Federated received:" : "Federaciones recibidas:",
    "Talk conversations:" : "Conversaciones de Talk:",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory limit:" : "Límite de memoria:",
    "Max execution time:" : "Tiempo máximo de ejecución:",
    "Upload max size:" : "Tamaño máximo de carga:",
    "OPcache Revalidate Frequency:" : "Frecuencia de revalidación de OPcache:",
    "Extensions:" : "Extensiones:",
    "Unable to list extensions" : "No se pueden enumerar las extensiones",
    "Show phpinfo" : "Mostrar phpinfo",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Herramienta de monitoreo externa",
    "Use this end point to connect an external monitoring tool:" : "Utilice este endpoint para conectar una herramienta de monitoreo externa.",
    "Copy" : "Copiar",
    "Output in JSON" : "Salida en JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Omitir actualizaciones de la aplicación (incluir las actualizaciones de las aplicaciones enviará una solicitud externa al app store)",
    "Skip server update" : "Omitir actualización del servidor",
    "To use an access token, please generate one then set it using the following command:" : "Para usar un token de acceso, por favor genere uno y luego configúrelo usando el siguiente comando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Luego pase el token con el encabezado \"NC-Token\" cuando solicite la URL anterior."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
